# Piano Viewer
## Displays key presses from MIDI.
[Screenshot](https://git.brokenmouse.studio/ever/pianoviewer/raw/branch/master/screenshot.png)

## Installation
* Install the package with `pip install pianoviewer`.

## Usage
* Get a list of available MIDI devices `pianoviewer -P`.
* Run `pianoviewer -p <YOUR MIDI DEVICE ID>` (this time the -p is small).
* If you want to adjust the settings, run `pianoviewer -h` to see what options are available.
